@@ -69,6 +69,9 @@ def during_callback():
 # What has to be done when the gfxlock is acquired?  What can't be
 # done?
 
+# TODO: Using any of the widgets in the time box should stop the
+# current animation.
+
 class GfxWindow(gfxwindowbase.GfxWindowBase):
     # This whole initialization sequence is complicated. See note in
     # gfxwindowbase.py.  preinitialize() is run from
@@ -76,7 +79,7 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
     # postinitialize() is run after the canvas is created.  Both are
     # run on the main thread.
 
-    def preinitialize(self, name, gfxmgr, clone):
+    def preinitialize(self, name, gfxmgr, settings, clone):
         debug.mainthreadTest()
         self.gtk = None
         self.closed = None # State data used at window-close time.
@@ -84,7 +87,7 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
         self.oofcanvas = None
         self.realized = 0
         self.zoomed = 0
-        self.settings = ghostgfxwindow.GfxSettings()
+        self.settings = settings or ghostgfxwindow.GfxSettings()
         self.mouseHandler = mousehandler.nullHandler # doesn't do anything
         self.rubberband = None
 
@@ -691,9 +694,19 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
             
     #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
+    ## TODO: When looping, can OOFCanvas save the bitmaps and not
+    ## recompute the layers?  The bitmaps would have to be recomputed
+    ## if layers changed.
+
+    ## TODO PYTHON3: There is some flickering when replaying at high
+    ## frame rates.  Is the canvas updating the screen before all of
+    ## the layers have been drawn?  Double buffering not working
+    ## correctly?
+
     def animate(self, menuitem, start, finish, times, frame_rate, style):
         menuitem.disable()
         prog = progress.getProgress("Animation", style.getProgressStyle())
+        self.animationProgressID = prog.id()
 
         # Construct a generator that produces the times of the
         # animation frames.  Python generators aren't thread safe in
@@ -720,7 +733,7 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
             # This menuitem shouldn't finish until the escapement
             # timeout callback has been cleared, which is indicated by
             # another event.
-            escapementDone = threading.Event()
+            self.escapementDone = threading.Event()
 
             # _stopAnimation indicates that the animation is complete,
             # either because it ran to the end, the user interrupted
@@ -728,10 +741,10 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
             self._stopAnimation = False
 
             # Start the escapement.
+            ## TODO: Add an animation test to the gui test suite.
             GLib.timeout_add(
-                interval=int(1000./frame_rate), # time between frames, in milliseconds
-                function=self._escapementCB,
-                user_data=(prog, escapementDone))
+                interval=int(1000./frame_rate), # time between frames, millisec
+                function=self._escapementCB)
 
             # Draw frames, after waiting for an escapement event.
             while not self._stopAnimation:
@@ -760,20 +773,28 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
 
             ## TODO: Use some other scheme for unthreaded mode.
 
-            escapementDone.wait()
+            self.escapementDone.wait()
             prog.finish()
+            self.animationProgressID = None
             menuitem.enable()
 
-    def _escapementCB(self, user_data):
-        prog, escapementDone = user_data
+    def _escapementCB(self):
         # Timeout callback that calls self._escapement.set()
         # periodically.  This is called on the main thread.
         self._escapement.set()
-        if prog.stopped() or self._stopAnimation:
-            self._stopAnimation = True
-            escapementDone.set()
-            return False        # don't reinstall time out callback
-        return True             # do reinstall timeout callback
+        try:
+            # The progress bar might have been deleted already, so
+            # findProgressByID might raise an exception.  Don't use
+            # findProgress, because it only works on the same thread
+            # where the Progress object was created.
+            if (progress.findProgressByID(self.animationProgressID).stopped()
+                or self._stopAnimation):
+                self._stopAnimation = True
+                self.escapementDone.set()
+                return False        # don't reinstall time out callback
+            return True             # do reinstall timeout callback
+        except:
+            return False
 
     def _timegenerator(self, style, times, start, finish):
         return iter(style.getTimes(times.times(start, finish, self)))
@@ -797,7 +818,6 @@ class GfxWindow(gfxwindowbase.GfxWindowBase):
     def toggleAntialias(self, menuitem, antialias):
         ghostgfxwindow.GhostGfxWindow.toggleAntialias(
             self, menuitem, antialias)
-        mainthread.runBlock(self.oofcanvas.setAntialias, (antialias,))
 
     # used by viewertoolbox zoom functions -- only 2D!
     def zoomFactor(self):
