@@ -30,10 +30,12 @@ import os
 import sys
 import traceback
 
-guidebugmenu = mainmenu.debugmenu.addItem(oofmenu.OOFMenuItem("GUI_Logging",
-                                                              ordering=1000,
-                                                              no_log=True,
-                                                              post_hook=None))
+guidebugmenu = mainmenu.debugmenu.addItem(oofmenu.OOFMenuItem(
+    "GUI_Logging",
+    ordering=1000,
+    no_log=True,
+    post_hook=None,
+    help="Tools for creating and loading log files of GUI sessions."))
 
 ###################################
 
