@@ -62,61 +62,82 @@ _debuglocks = False
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
-class NewLayerPolicy(enum.EnumClass(
-        ("Never", "Don't automatically create any display layers."),
-        ("Single", "Automatically add new graphics layers for Images, Skeletons, and Meshes if the graphics window doesn't contain any similar layers for other objects.  New graphics windows will automatically add layers for pre-existing objects if they are unique."),
-        ("Always", "Automatically add display layers for all newly created Images, Skeletons, and Meshes."))):
+class NewLayerPolicy(
+        enum.EnumClass(
+            ("Never",
+             "Don't automatically create any display layers."),
+            ("Single",
+             """Automatically add new graphics layers for
+             Images, Skeletons, and Meshes if the graphics window doesn't
+             contain any similar layers for other objects.  New graphics
+             windows will automatically add layers for pre-existing objects
+             if they are unique."""),
+            ("Always",
+             """Automatically add display layers for all newly created
+             Images, Skeletons, and Meshes."""))):
     tip = "How the graphics window reacts when new Images, Skeletons, or Meshes are created."
+    discussion='<para>See <xref linkend="Section-Graphics-New-Layer-Policy"/>.</para>'
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
 class OutputImageFormat(enum.EnumClass(
-        "pdf", "png")):
-    pass
+        ("pdf", "Save image as a pdf file."),
+        ("png", "Save image as a png file."))):
+    tip="File format for the image."
+    discussion="""<para>Images can be saved as either pdf or png files.</para>"""
 
 if debug.debug():
-    enum.addEnumName(OutputImageFormat, "datadump")
+    enum.addEnumName(OutputImageFormat, "datadump",
+                     help="For debugging only.")
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
+default_settings = dict(
+    bgcolor = color.white.opaque(),
+    zoomfactor = 1.5,
+    margin = 0.05,
+    longlayernames = False,     # Use long form of layer reprs.
+    listall = False,            # are all layers to be listed?
+    antialias = True,
+    aspectratio = 5,            # Aspect ratio of the contourmap.
+    contourmap_markersize = 2,  # Size in pixels of contourmap marker.
+    contourmap_markercolor = color.gray50, # Contourmap position marker color.
+    newlayerpolicy = NewLayerPolicy("Never")
+)    
+
 class GfxSettings:
     # Stores all the settable parameters for a graphics
-    # window. Variables defined at the class level are the default
-    # values. Assigning to a variable sets *both* the instance and
-    # default values.  Therefore a new window will always use the
-    # latest settings.
+    # window. Assigning to a variable sets *both* the instance and
+    # default values so that a new window will always use the latest
+    # settings.
 
-    ## TODO: Use Python properties, instead of __setattr__.
+    ## TODO? Use Python properties, instead of __setattr__.  Can that
+    ## be done without writing separate setter and getter routines for
+    ## each setting?  That would make it difficult to add new
+    ## settings.
 
-    bgcolor = color.white.opaque()
-    zoomfactor = 1.5
-    margin = 0.05
-    longlayernames = False      # Use long form of layer reprs.
-    listall = False             # are all layers to be listed?
-    antialias = True
-    aspectratio = 5             # Aspect ratio of the contourmap.
-    contourmap_markersize = 2   # Size in pixels of contourmap marker.
-    contourmap_markercolor = color.gray50 # Color of contourmap position marker.
-    newlayerpolicy = NewLayerPolicy("Never")
     def __init__(self):
-        # Copy all default (class) values into local (instance) variables.
-        self.__dict__['timestamps'] = {}
-        for key,val in GfxSettings.__dict__.items():
-            # Exclude '__module__', etc, as well as all methods (such
-            # as getTimeStamp).  Because (apparently) we're accessing
-            # the methods via the dictionary, they're not recognized
-            # as methods, and we have to check for FunctionType
-            # instead of MethodType or UnboundMethodType.
-            if key[0] != '_' and not isinstance(val, types.FunctionType):
-                self.__dict__[key] = val
-                self.timestamps[key] = timestamp.TimeStamp()
+        self.__dict__['timestamps'] = {} # don't use setattr for this!
+        # Initialize to the default values
+        for key, val in default_settings.items():
+            self.__dict__[key] = val
+            self.timestamps[key] = timestamp.TimeStamp()
     def __setattr__(self, attr, val):
-        self.__dict__[attr] = val       # local value
-        setattr(GfxSettings, attr, val) # default value
-        self.timestamps[attr].increment()
+        self.__dict__[attr] = val 
+        default_settings[attr] = val
+        if attr in self.timestamps:
+            self.timestamps[attr].increment()
+        else:
+            self.timestamps[attr] = timestamp.TimeStamp()
     def getTimeStamp(self, attr):
         return self.timestamps[attr]
 
+    def clone(self):
+        copy = GfxSettings()
+        for attr in default_settings.keys():
+            setattr(copy, attr, getattr(self, attr))
+        return copy
+
 
 # Modules (eg, image or engine) can add graphics window settings by
 # calling defineGfxSetting().  They should do this at initialization
@@ -126,7 +147,7 @@ class GfxSettings:
 # signal.
 
 def defineGfxSetting(name, val):
-    exec(f"GfxSettings.{name} = val") # what's the right way to do this?
+    default_settings[name] = val
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
@@ -146,7 +167,9 @@ class ContourMapData:
 class GhostGfxWindow:
     initial_height = 400
     initial_width = 800
-    def __init__(self, name, gfxmanager, clone=0):
+    def __init__(self, name, gfxmanager, settings=None, clone=False):
+        if not hasattr(self, 'settings'):
+            self.settings = settings or GfxSettings()
         self.name = name
         self.gfxmanager = gfxmanager
         if not hasattr(self, 'gfxlock'):
@@ -161,11 +184,9 @@ class GhostGfxWindow:
         # sorts of time.
         self.displayTime = 0.0
         self.displayTimeChanged = timestamp.TimeStamp()
-        if not hasattr(self, 'settings'):
-            self.settings = GfxSettings()
 
         self.oofcanvas = mainthread.runBlock(self.newCanvas)
-        self.oofcanvas.setAntialias(self.settings.antialias)
+        self.oofcanvas.setAntialias(bool(self.settings.antialias))
         self.oofcanvas.setBackgroundColor(
             color.canvasColor(self.settings.bgcolor))
         self.oofcanvas.setMargin(self.settings.margin)
@@ -204,9 +225,10 @@ class GhostGfxWindow:
             help='Make a copy of this window.',
             discussion="""<para>
             Duplicate this <link linkend='Chapter-Graphics'>Graphics
-            window</link>.  All the settings and <link
-            linkend='Section-Graphics-Layer'>layers</link> will be
-            duplicated as well.
+            window</link>.  The <link
+            linkend='Section-Graphics-Layer'>layers</link> and most of the
+            <link linkend="MenuItem-OOF.Graphics_n.Settings">settings</link>
+            will be duplicated as well.
             </para>"""
             ))
         filemenu.addItem(OOFMenuItem(
@@ -230,9 +252,8 @@ class GhostGfxWindow:
                     "background", True,
                     tip="Fill the background?")                       
             ],
-            help="Save the contents of the graphics window as a pdf file.",
+            help="Save the contents of the graphics window as an image file.",
             discussion=xmlmenudump.loadFile(
-                # TODO GTK3: Update this file
                 'DISCUSSIONS/common/menu/graphicssave.xml')
             ))
         filemenu.addItem(OOFMenuItem(
@@ -264,7 +285,9 @@ class GhostGfxWindow:
                     tip="Upper right corner of the saved region,"
                     " in physical coordinates.")
                 ],
-            help="Save a region of the graphics window as a pdf file."))
+            help="Save a region of the graphics window as an image file.",
+            discussion=xmlmenudump.loadFile(
+                'DISCUSSIONS/common/menu/graphicssaveregion.xml')))
             
         filemenu.addItem(OOFMenuItem(
             'Save_Contourmap',
@@ -334,7 +357,14 @@ class GhostGfxWindow:
             filemenu.addItem(OOFMenuItem(
                 'DumpLayers',
                 callback=self.dumpLayers,
-                params=[parameter.StringParameter('filename')],
+                params=[parameter.StringParameter('filename',
+                                                  tip="File name prefix.")],
+                help="Save each graphics layer as a separate png file.",
+                discussion="""<para> Save each individual graphics
+                layer in a png file, named
+                <userinput>filename</userinput>XX.png, where XX is an
+                integer. Only available if the window was opened in
+                debug mode. </para>"""
                 ))
 
         filemenu.addItem(OOFMenuItem(
@@ -373,7 +403,8 @@ class GhostGfxWindow:
             ellipsis=True,
             gui_title="New Graphics Layer", # used in the dialog box
             params=[
-                whoville.WhoClassParameter("category"),
+                whoville.WhoClassParameter(
+                    "category", tip="The kind of object to display."),
                 whoville.AnyWhoParameter(
                     "what", tip="The object to display."),
                 display.DisplayMethodParameter(
@@ -387,7 +418,8 @@ class GhostGfxWindow:
             'Edit',
             callback=self.editLayerCB,
             params=[IntParameter('n', 0, tip="Layer to edit."),
-                    whoville.WhoClassParameter("category"),
+                    whoville.WhoClassParameter(
+                        "category", tip="The kind of object to display"),
                     whoville.AnyWhoParameter(
                         "what", tip="The object to display"),
                     display.DisplayMethodParameter(
@@ -569,8 +601,11 @@ linkend="MenuItem-OOF.Graphics_n.Layer.Freeze"/>.</para>
             'New_Layer_Policy',
             callback=self.setNewLayerPolicy,
             params=[enum.EnumParameter('policy', NewLayerPolicy,
-                                       value=self.settings.newlayerpolicy)],
-            help="When to create new graphics layers."
+                                       value=self.settings.newlayerpolicy,
+                                       tip=parameter.emptyTipString)],
+            help="When to create new graphics layers.",
+            discussion=xmlmenudump.loadFile(
+                "DISCUSSIONS/common/menu/newlayerpolicy.xml")
         ))
         settingmenu.addItem(CheckOOFMenuItem(
             'List_All_Layers',
@@ -742,6 +777,9 @@ linkend="MenuItem-OOF.Graphics_n.Layer.Freeze"/>.</para>
 
         self.sensitize_menus()
 
+        # If this is a clone, the cloning process will copy the
+        # predefined layers from the original, and we don't have to
+        # create them here.
         if not clone:
             self.createPredefinedLayers()
 
@@ -994,13 +1032,16 @@ linkend="MenuItem-OOF.Graphics_n.Layer.Freeze"/>.</para>
         self.selectedLayer = self.layers[n]
         self.incorporateLayer(how, who)
 
+    ## TODO LATER: Add GUI test for cloning a graphics window.
+    ## Testing that all the settings have been applied correctly to
+    ## the OOFCanvas will require some additional OOFCanvas code.
     def cloneWindow(self, *args):
         self.acquireGfxLock()
         try:
-            clone = self.gfxmanager.openWindow(clone=1)
-            clone.settings = copy.deepcopy(self.settings)
+            clone = self.gfxmanager.openWindow(clone=True,
+                                               settings=self.settings.clone())
             for layer in self.layers:
-                clone.incorporateLayer(layer)
+                clone.incorporateLayer(layer.clone(), layer.who)
                 clone.deselectLayer(clone.selectedLayerNumber())
             if self.selectedLayer is not None:
                 clone.selectLayer(self.layerID(self.selectedLayer))
@@ -1102,7 +1143,10 @@ linkend="MenuItem-OOF.Graphics_n.Layer.Freeze"/>.</para>
 
     def toggleAntialias(self, menuitem, antialias):
         self.settings.antialias = antialias
-        self.oofcanvas.setAntialias(antialias)
+        # Swigged functions like setAntialias require their boolean
+        # args to be actual bools, but gtk3 sets antialias to either 0
+        # or 1.
+        self.oofcanvas.setAntialias(bool(antialias))
 
     def toggleContourpane(self, menuitem, contourpane):
         self.settings.showcontourpane = contourpane
@@ -1622,12 +1666,22 @@ mainmenu.gfxdefaultsmenu.addItem(oofmenu.OOFMenuItem(
     discussion="<para> Set the initial size of graphics windows. </para>"
     ))
 
+##########
+
+# Global default setting for the new layer policy.  This applies to
+# all new windows, not existing ones.
+
 def _setDefaultNewLayerPolicy(menuitem, policy):
-    GfxSettings.newlayerpolicy = policy
+    default_settings["newlayerpolicy"] = policy
 
 mainmenu.gfxdefaultsmenu.addItem(oofmenu.OOFMenuItem(
     'New_Layer_Policy',
     callback=_setDefaultNewLayerPolicy,
-    params=[enum.EnumParameter('policy', NewLayerPolicy,
-                               value=GfxSettings.newlayerpolicy)],
-    help = "When to create new graphics layers."))
+    params=[enum.EnumParameter(
+        'policy', NewLayerPolicy,
+        value=default_settings["newlayerpolicy"],
+        tip='New layer policy for newly created windows.')],
+    help = "When to create new graphics layers in new windows.",
+    discussion=xmlmenudump.loadFile(
+        "DISCUSSIONS/common/menu/defaultnewlayerpolicy.xml")
+))
