@@ -114,7 +114,13 @@ _startupmenu = _filemenu.addItem(OOFMenuItem(
     'LoadStartUp',
     secret=True,
     help="Load start-up datafiles and scripts.",
-    discussion="<para>Commands to load datafiles and scripts at start-up time.</para>"))
+    discussion="""<para> Commands to load datafiles and scripts from
+    command line arguments at start-up time. These commands are the
+    same as the ones in <xref linkend="MenuItem-OOF.File.Load"/> but
+    have their own copies of the parameters to avoid affecting default
+    values. </para>""",
+    xrefs=["Section-Running"]
+))
 
 class PScriptLoader(scriptloader.ScriptLoader):
     # A ScriptLoader that supports a progress bar.
@@ -176,7 +182,8 @@ _loadmenu.addItem(OOFMenuItem(
     ellipsis=1,
     accel='l',
     help="Execute a Python script.",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loadscript.xml')
+    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loadscript.xml'),
+    xrefs=["Section-Running"]
     ))
 
 _startupmenu.addItem(OOFMenuItem(
@@ -191,7 +198,7 @@ _startupmenu.addItem(OOFMenuItem(
     disabled=config.nanoHUB(),  # loading arbitrary scripts is a
                                 # security hole on nanoHUB
     help="Execute a Python script.",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loadscript.xml')
+    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loadscript.xml'),
     ))
 
 # "Data" files are distinguished from scripts in that they're not read
@@ -214,7 +221,8 @@ _loadmenu.addItem(OOFMenuItem(
                                                 tip="Name of the file.")],
     ellipsis=1,
     help="Load a data file.",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loaddatafile.xml')
+    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loaddatafile.xml'),
+    xrefs=["Section-Running"]
     ))
 
 _startupmenu.addItem(OOFMenuItem(
@@ -225,7 +233,7 @@ _startupmenu.addItem(OOFMenuItem(
                                                 tip="Name of the file.")],
     ellipsis=1,
     help="Load a data file.",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loaddatafile.xml')
+    discussion=xmlmenudump.loadFile('DISCUSSIONS/common/menu/loaddatafile.xml'),
     ))
 
 OOF.addItem(oofmenu.OOFMenuItem(
@@ -405,7 +413,9 @@ settingsmenu.addItem(oofmenu.OOFMenuItem(
     'Random_Seed',
     callback=_randomseed,
     ordering=3.5,
-    params=[parameter.IntParameter('seed', 17)]
+    params=[parameter.IntParameter('seed', 17, tip=parameter.emptyTipString)],
+    help="Seed the random number generator.",
+    discussion=xmlmenudump.loadFile("DISCUSSIONS/common/menu/randomseed.xml")
 ))
 
 def _setdigits(menuitem, digits):
@@ -417,7 +427,9 @@ settingsmenu.addItem(oofmenu.OOFMenuItem(
     ordering=3,
     params=[parameter.NonNegativeIntParameter(
         'digits', runtimeflags.digits(),
-        tip='Number of digits to show after the decimal point.')]
+        tip='Number of digits to show after the decimal point.')],
+    help="Set the precision for numbers in the GUI.",
+    discussion=xmlmenudump.loadFile("DISCUSSIONS/common/menu/digits.xml")
 ))
 
 ################################
@@ -431,7 +443,8 @@ _annotatelogmenu = _filemenu.addItem(OOFMenuItem(
     discussion="<para>Write info directly to the log file.</para>",
     callback = _annotatelogmenucallback,
     ordering=200,
-    params=[parameter.StringParameter(name="message"),]
+    params=[parameter.StringParameter(name="message",
+                                      tip="Data to include in the log file."),]
     ))
 
 ##################################
@@ -487,11 +500,14 @@ def openGfx(menuitem):
     window = gfxManager.openWindow()
     window.drawAtTime(time=window.latestTime(), zoom=True)
     
-_graphicsmenu.addItem(OOFMenuItem("New",
-                                  callback=openGfx,
-                                  help="Open a new graphics window.",
-                                  accel='g',
-                                  discussion="<para>Create a new <link linkend='Chapter-Graphics'>Graphics Window</link>.</para>"))
+_graphicsmenu.addItem(OOFMenuItem(
+    "New",
+    callback=openGfx,
+    help="Open a new graphics window.",
+    accel='g',
+    discussion="""<para>Create a new <link
+    linkend='Chapter-Graphics'>Graphics Window</link>.</para>"""
+))
 
 _windowmenu.addItem(_graphicsmenu)
 
@@ -509,15 +525,27 @@ Viewer</link> window, if it is open. If not, open it.
 
 ## Help menu
 
-helpmenu = OOF.addItem(OOFMenuItem('Help', help_menu=1))
+helpmenu = OOF.addItem(OOFMenuItem(
+    'Help',
+    help_menu=1,
+    help="Tutorials and debugging tools.",
+    discussion=
+    """<para>Tutorials, debugging tools, and documentation tools.
+    Some of these items only appear if &oof2; is started with the
+    <link
+    linkend="Section-Running"><userinput>--debug</userinput></link>
+    option.</para>"""
+))
 
 debugmenu = helpmenu.addItem(OOFMenuItem(
     'Debug',
-    discussion=
-    """
-<para>Tools for figuring out what's going on when it's not going well.
-Mostly of interest to the developers.</para>
-"""
+    help="Tools for debugging.",
+    discussion= """<para>Tools for figuring out what's going on when
+    it's not going well.  Mostly of interest to the developers.  Some
+    of these commands only appear in the GUI if &oof2; is started with
+    the <link
+    linkend="Section-Running"><userinput>--debug</userinput></link>
+    option.</para>"""
     ))
 
 def set_debug(menuitem, state):
@@ -546,7 +574,11 @@ debugmenu.addItem(CheckOOFMenuItem(
     'Switchboard_Stack_Tracking',
     switchboard.useMessageStackFlag,
     callback=switchboard.useMessageStackCB,
-    help='Keep track of current switchboard calls.'))
+    help='Keep track of current switchboard calls.',
+    discussion="""<para>Keep track of which switchboard calls have led
+    to other switchboard calls, making it easier to find cause and
+    effect when debugging.</para>"""
+))
     
 
 if debug.debug():
@@ -554,7 +586,11 @@ if debug.debug():
         "Sandbox",
         callback=None,
         accel='d',
-        threadable=oofmenu.UNTHREADABLE))
+        threadable=oofmenu.UNTHREADABLE,
+        help="Open the sandbox window.",
+        discussion="""<para>A place for developers to play with gtk
+        code in the &oof2; environment.</para>"""
+    ))
         
 ####
 
@@ -564,17 +600,28 @@ def _startMemMonitor(menuitem, filename):
 def _stopMemMonitor(menuitem):
     utils.stopMemoryMonitor()
 
-memmenu = debugmenu.addItem(OOFMenuItem('Memory_Monitor'))
+memmenu = debugmenu.addItem(OOFMenuItem(
+    'Memory_Monitor',
+    discussion="""<para>Tools for debugging memory issues.  See
+    <filename>SRC/common/utils.py</filename>.</para>"""
+))
 
 memmenu.addItem(OOFMenuItem(
     'Start',
     callback=_startMemMonitor,
-    params=[filenameparam.WriteFileNameParameter("filename")],
+    params=[
+        filenameparam.WriteFileNameParameter(
+            "filename", tip="Log file name.")],
+    help="Start logging memory use.",
+    discussion="<para>Start logging memory use.</para>"
     ))
 
 memmenu.addItem(OOFMenuItem(
     'Stop',
-    callback=_stopMemMonitor))
+    callback=_stopMemMonitor,
+    help="Stop logging memory use.",
+    discussion="<para>Stop logging memory use.</para>"
+))
 
 ####
 
@@ -651,7 +698,11 @@ treated as errors and will abort the current calculation.</para>
 
 ## Profiling functions, in the Debug menu
 
-profmenu = debugmenu.addItem(OOFMenuItem('Profile'))
+profmenu = OOFMenuItem('Profile')
+
+## TODO: The profiling menu is commented out because it doesn't work
+## anymore.  Fix it and uncomment the next line.
+# debugmenu.addItem(profmenu)
 prof = None
 
 def profile_start(menuitem, filename, fudge):
@@ -685,7 +736,9 @@ profmenu.addItem(OOFMenuItem(
     callback=profile_stop,
     threadable = oofmenu.UNTHREADABLE,
     help="Stop measuring execution time.",
-    discussion="<para>Stop profiling, and save the data in the file specified in <xref linkend='MenuItem-OOF.Help.Debug.Profile.Start'/>.</para>"
+    discussion="""<para>Stop profiling, and save the data in the file
+    specified in <xref
+    linkend='MenuItem-OOF.Help.Debug.Profile.Start'/>.</para>"""
                              ))
 
 def proffudge(menuitem, iterations):
@@ -797,8 +850,11 @@ errmenu.addItem(OOFMenuItem('Infinite_Loop', callback=loop,
 def spinCycle(menuitem, nCycles):
     cdebug.spinCycle(nCycles)
 
-debugmenu.addItem(OOFMenuItem('SpinCycle', callback=spinCycle,
-                              params=[IntParameter('nCycles', 100000)]))
+debugmenu.addItem(OOFMenuItem(
+    'SpinCycle', callback=spinCycle,
+    params=[IntParameter('nCycles', 100000, tip="How many cycles to run.")],
+    help="Eat up some cpu cycles.",
+    discussion="<para>I don't remember why this was needed.</para>"))
 
 import os
 from ooflib.SWIG.common import lock
@@ -858,5 +914,9 @@ debugmenu.addItem(OOFMenuItem(
         'Random',
         callback=_random,
         secret=not debug.debug(),
-        params=[IntParameter('n', 10, tip='How many')],
-        help='For debugging'))
+        params=[IntParameter('n', 10, tip='How many numbers to generate.')],
+        help='Generate some random numbers.',
+    discussion="""<para>For debugging the random number generator.
+    Being able to generate reproducible random numbers is important
+    for the test suite.</para>"""
+))
