@@ -71,6 +71,26 @@ def regclassID(regclass):
 def registrationID(reg):
     return "RegisteredClass-%s" % reg.subclass.__name__
 
+###################
+
+# Convert a list of xml ids to a list of links for the "See Also"
+# sections of menuitems and registeredclasses.  The list items are
+# either xml ids (strings) or a tuple (xmlid, text). 
+
+def xrefListing(xrefs):
+    texts = []
+    done = []                   # check for duplicates
+    for xref in xrefs:
+        if xref not in done:
+            if isinstance(xref, str):
+                texts.append(f'<xref linkend="{xref}"/>')
+            elif isinstance(xref, tuple):
+                texts.append(f'<xref linkend="{xref[0]}" endterm="{xref[1]}"/>')
+            done.append(xref)
+    return ", ".join(texts)
+        
+    
+
 ###################
 
 # RegisteredClasses, Registrations, MenuItems, and Enums (and possibly
@@ -93,14 +113,17 @@ class DiscussionFile:
         self.filename = filename
         self.func = func
     def read(self, obj):
+        # This comment makes it easier to find the source file in case
+        # the xml processor reports errors in the combined file.
+        namecomment = f"<!-- FILE: {self.filename} -->\n"
         if self.filename:
             phile = open(self.filename, 'r')
             text = phile.read()
         else:
             text = None
         if self.func:
-            return self.func(text, obj)
-        return text
+            return namecomment + self.func(text, obj)
+        return namecomment + text
 
 class DiscussionFunc:
     def __init__(self, func):
@@ -119,13 +142,14 @@ def getDiscussion(obj):
 def getHelp(obj):                       # get help, helpstr, or tip
     for helpattr in ("helpstr", "help", "tip"):
         try:
-            help = getattr(obj, helpattr)
+            whelp = getattr(obj, helpattr)
         except AttributeError:
             pass
         else:
-            if isinstance(help, (str, bytes)):
-                return help
-            return help.read(obj)
+            if isinstance(whelp, (str, bytes)):
+                return whelp
+            return whelp.read(obj)
+    raise AttributeError(obj, "helpstr, help, or tip")
 
 ##################    
 
@@ -195,12 +219,19 @@ def dumpMenu(file, menu, toplevel):
             try:
                 help = getHelp(item)
                 if help:
-                    print("--", help, file=file)
+                    print("&#x2014;", help, file=file)
             except AttributeError:
                 pass
             print(" </simpara></listitem>", file=file)
     print("</itemizedlist>", file=file)
 
+    xrefs = menu.xmlXRefs()
+    if xrefs:
+        print(" <simplesect>", file=file)
+        print("   <title>See Also</title>", file=file)
+        print(f"   <simpara>{xrefs}</simpara>", file=file)
+        print(" </simplesect>", file=file)
+
     if not toplevel:
         print("</section> <!-- %s -->" % path, file=file)
 
@@ -255,15 +286,17 @@ def dumpMenuItem(file, menuitem):
         print("  <listitem><simpara>", file=file)
         print("   Callback: function <function>%s</function> in module <filename>%s</filename>" % (fname, mname), file=file)
         print("  </simpara></listitem>", file=file)
-    # print >> file, "  <listitem><simpara>"
-    # print >> file, "    Threadability: <constant>%s</constant>" % \
-    #       menuitem.threadable
-    # print >> file, "  </simpara></listitem>"
-    if menuitem.options:
+
+    # Menu items are enabled and disabled dynamically, so the current
+    # state of the flag isn't relevant to the documentation.
+    ## TODO: "disabled" shouldn't be an OOFMenuItem option.
+    if menuitem.options and list(menuitem.options.keys()) != ['disabled']:
         print("  <listitem><simpara>", file=file)
         print("   Options:", file=file)
         for key, val in list(menuitem.options.items()):
-            print(" <varname>%s</varname>=<constant>%s</constant>" %(key, repr(val)), file=file)
+            if key != "disabled":
+                print(" <varname>%s</varname>=<constant>%s</constant>"
+                      %(key, repr(val)), file=file)
         print("  </simpara></listitem>", file=file)
 
     menuitem.xmlParams(file)
@@ -278,6 +311,14 @@ def dumpMenuItem(file, menuitem):
     except AttributeError:
         print("  <para>MISSING DISCUSSION: %s</para>" % path, file=file)
     print(" </refsect1>", file=file)
+
+    xrefs = menuitem.xmlXRefs()
+    if xrefs:
+        print(" <refsect1>", file=file)
+        print("   <title>See Also</title>", file=file)
+        print(f"   <simpara>{xrefs}</simpara>", file=file)
+        print(" </refsect1>", file=file)
+    
     print("</refentry>", file=file)
 
 ###################        
@@ -444,7 +485,7 @@ may be members of more than one
         except AttributeError:
             tip = "MISSING TIP STRING: %s" % regclassname
         print(" <listitem><simpara>", file=file)
-        print("  <xref linkend='%s'/> -- %s" % (regclassID(regclass),\
+        print("  <xref linkend='%s'/> &#x2014; %s" % (regclassID(regclass),\
                                                          tip), file=file)
         print(" </simpara></listitem>", file=file)        
     print(" </itemizedlist>", file=file)
@@ -481,7 +522,7 @@ may be members of more than one
                 except AttributeError:
                     tip = "MISSING TIP STRING: %s" % reg.subclass.__name__
                 print("   <listitem><simpara>", file=file)
-                print("    <link linkend='%s'>%s (<classname>%s</classname>)</link> -- %s" % \
+                print("    <link linkend='%s'>%s (<classname>%s</classname>)</link> &#x2014; %s" % \
                       (registrationID(reg), reg.name(), reg.subclass.__name__,
                        tip), file=file)
                 print("   </simpara></listitem>", file=file)
@@ -495,7 +536,15 @@ may be members of more than one
             print("<para>MISSING DISCUSSION: %s</para>" \
                   % regclassname, file=file)
         print("  </refsect1>", file=file)
-        print(" </refentry>", file=file)
+        xrefs = getattr(regclass, "xrefs", [])
+        if xrefs:
+            print("<simplesect>", file=file)
+            print("<title>See Also</title>", file=file)
+            print(f"<simpara>{xrefListing(xrefs)}</simpara>", file=file)
+            print("</simplesect>", file=file)
+
+        print(" </refentry>", file=file) # end refentry for registered base class
+
     print("</section>", file=file)
 
     subclassnames = sorted(list(registrationdict.keys()))
@@ -515,7 +564,7 @@ may be members of more than one
             tip = getHelp(reg)
         except AttributeError:
             tip = "MISSING TIP STRING: %s" % name
-        print("    <xref linkend='%s'/> -- %s" % \
+        print("    <xref linkend='%s'/> &#x2014; %s" % \
               (registrationID(reg), tip), file=file)
         print("  </simpara></listitem>", file=file)
     print(" </itemizedlist>", file=file)
@@ -540,7 +589,7 @@ may be members of more than one
 
         print("  <refsynopsisdiv><simpara>", file=file)
         args = utils.stringjoin(['<varname>%s</varname>' % p.name
-             for p in reg.params], ',')
+             for p in reg.params], ', ')
         print("   <classname>%s</classname>(%s)" % (name, args), file=file)
         print("  </simpara></refsynopsisdiv>", file=file)
         
@@ -581,6 +630,12 @@ may be members of more than one
         except AttributeError:
             print("<para>MISSING DISCUSSION: %s</para>" % name, file=file)
         print("  </refsect1>", file=file)
+        if reg.xrefs:
+            print("   <refsect1>", file=file)
+            print("   <title>See Also</title>", file=file)
+            print(f"   <simpara>{xrefListing(reg.xrefs)}</simpara>",
+                  file=file)
+            print("   </refsect1>", file=file)
         print(" </refentry>", file=file)
 
     print("</section>", file=file)         # end of registered subclasses
@@ -636,7 +691,7 @@ def enumSection(file):
         except AttributeError:
             tip = "MISSING ENUM TIP STRING: %s" % enumname
         print("<listitem><simpara>", file=file)
-        print(" <xref linkend='Enum-%s'/> -- %s" % (enumname, tip), file=file)
+        print(" <xref linkend='Enum-%s'/> &#x2014; %s" % (enumname, tip), file=file)
         print("</simpara></listitem>", file=file)        
     print("</itemizedlist>", file=file)
     
