@@ -8,7 +8,7 @@
 # versions of this software, you first contact the authors at
 # oof_manager@nist.gov. 
 
-import math, types
+import math
 from ooflib.SWIG.common import config
 from ooflib.common import debug
 from ooflib.common import registeredclass
@@ -36,30 +36,26 @@ FloatRangeParameter = parameter.FloatRangeParameter
 ## instead of floats 0-1.
 
 class Color(registeredclass.ConvertibleRegisteredClass):
-    # Generic comparator for colors.  Subclasses must provide
-    # getRed(), getGreen() and getBlue() functions, which they need
-    # for other reasons anyways.
-    def __cmp__(self,other):
-        try:
-            if self.getRed() < other.getRed(): return -1
-            if self.getRed() > other.getRed(): return 1
-            if self.getGreen() < other.getGreen(): return -1
-            if self.getGreen() > other.getGreen(): return 1
-            if self.getBlue() < other.getBlue(): return -1
-            if self.getBlue() > other.getBlue(): return 1
-            if self.getAlpha() < other.getAlpha(): return -1
-            if self.getAlpha() > other.getAlpha(): return 1
-        except AttributeError:
-            return 1
-        return 0
-    # Also need to over-ride RegisteredClass's __eq__ and __ne__ functions.
+    def keyfn(self):    # For sorting.  Do we need it?
+        return (self.getRed(), self.getGreen(), self.getBlue(), self.getAlpha())
     def __eq__(self,other):
-        return self.__cmp__(other)==0
+        if isinstance(other, Color):
+            return (self.getRed() == other.getRed() and
+                    self.getGreen() == other.getGreen() and
+                    self.getBlue() == other.getBlue() and
+                    self.getAlpha() == other.getAlpha())
+        return False
     def __ne__(self,other):
-        return self.__cmp__(other)!=0
-    
-    def rgb(self):
+        if isinstance(other, Color):
+            return (self.getRed() != other.getRed() or
+                    self.getGreen() != other.getGreen() or
+                    self.getBlue() != other.getBlue() or
+                    self.getAlpha() != other.getAlpha())
+        return True
+    def rgb(self):              # TODO: Is this used?
         return (self.getRed(), self.getGreen(), self.getBlue())
+    def rgba(self):             # TODO: Is this used?
+        return (self.getRed(), self.getGreen(), self.getBlue(), self.getAlpha())
 
     tip = "Various ways of describing a color."
     discussion = """<para>
@@ -69,9 +65,6 @@ class Color(registeredclass.ConvertibleRegisteredClass):
     format in which a color was specified.
     </para>"""
 
-    def rgba(self):
-        return (self.getRed(), self.getGreen(), self.getBlue(), self.getAlpha())
-
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
 # Subclasses of TranslucentColor should define opaque(), which returns
@@ -91,49 +84,13 @@ class OpaqueColor(TranslucentColor):
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
     
-# Structured type to hold the base values for color parameters, and
-# which can be type-checked.  Also contains the comparator for colors.
-# (TODO: Is there any reason not to just use RGBAColor as the base
-# representation?)
-class ColorValueBase:
-    def __init__(self,red,green,blue,alpha=1):
-        self.red = red
-        self.green = green
-        self.blue = blue
-        self.alpha = alpha
-    def getRed(self):
-        return self.red
-    def getGreen(self):
-        return self.green
-    def getBlue(self):
-        return self.blue
-    def getAlpha(self):
-        return self.alpha
-    # Comparator, same semantics as instance comparator, but usable
-    # if you don't yet have an instance.  (Does this ever happen?)
-    def __cmp__(self, other):
-        try:
-            if self.red < other.red: return -1
-            if self.red > other.red: return 1
-            if self.green < other.green: return -1
-            if self.green > other.green: return 1
-            if self.blue < other.blue: return -1
-            if self.blue > other.blue: return 1
-            if self.alpha < other.alpha: return -1
-            if self.alpha > other.alpha: return 1
-        except AttributeError:
-            return 1                    # 'other' is (probably) not a CVB.
-        return 0
-    def __repr__(self):
-        return "ColorValueBase(red=%.5f, green=%.5f, blue=%.5f, alpha=%.5f)" % \
-               (self.red, self.green, self.blue, self.alpha)
-    
 # Registration assigns the conversion routines, which make
 # Color into a nontrivial convertible class.  "to_base" and
 # "from_base" arguments are required at this level, in general.
 # For the particular case of Color, however, all of the instances
 # can answer "base" queries (r, g, or b) more efficiently at
 # the instance level, so "to_base" functions are not provided.
+
 class ColorRegistration(registeredclass.ConvertibleRegistration):
     # ConvertibleRegistration.to_base is only called by
     # ConvertibleRegistration.getParamValuesAsBase and by
@@ -142,8 +99,8 @@ class ColorRegistration(registeredclass.ConvertibleRegistration):
     # any to_base functions.
     def getParamValuesAsBase(self):
         temp = self()
-        return ColorValueBase(temp.getRed(), temp.getGreen(), temp.getBlue(),
-                              temp.getAlpha())
+        return RGBAColor(temp.getRed(), temp.getGreen(), temp.getBlue(),
+                         temp.getAlpha())
 
 #=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=##=--=#
 
@@ -173,30 +130,17 @@ class RGBColor(OpaqueColor):
     def __hash__(self):
         return hash((self.red, self.green, self.blue))
     def __eq__(self, other):
-        try:
-            if self.red < other.red or self.red > other.red or \
-                   self.green < other.green or self.green > other.green or \
-                   self.blue < other.blue or self.blue > other.blue or \
-                   self.alpha < other.alpha or self.alpha > other.alpha:
-                return 0
-        except AttributeError:
-            return Color.__eq__(self, other)
-        return 1
+        if isinstance(other, RGBColor):
+            return (self.red == other.red and
+                    self.green == other.green and
+                    self.blue == other.blue)
+        return Color.__eq__(self, other)
     def __ne__(self, other):
-        return 1 - self.__eq__(other)
-    def __cmp__(self, other):
-        try:
-            if self.red < other.red: return -1
-            if self.red > other.red: return 1
-            if self.green < other.green: return -1
-            if self.green > other.green: return 1
-            if self.blue < other.blue: return -1
-            if self.blue > other.blue: return 1
-            if self.alpha < other.alpha: return -1
-            if self.alpha > other.alpha: return 1
-        except AttributeError:
-            return Color.__cmp__(self, other)
-        return 0
+        if isinstance(other, RGBColor):
+            return (self.red != other.red or
+                    self.green != other.green or
+                    self.blue != other.blue)
+        return Color.__ne__(self, other)
 
     # RGBColor overrides the default repr defined in RegisteredClass,
     # because the default one writes too many digits. The repr is used
@@ -210,8 +154,8 @@ class RGBColor(OpaqueColor):
                                                             self.blue)
 
 # RGB conversion functions are nearly trivial.
-def _rgb_from_base(rgb, base):
-    if isinstance(base,ColorValueBase):
+def _rgb_from_base(base):
+    if isinstance(base, RGBAColor):
         return [base.red, base.green, base.blue]
 
 def rgb_from_hex(hexstr):
@@ -255,8 +199,8 @@ class RGBAColor(TranslucentColor):
     def opaque(self):
         return RGBColor(self.red, self.green, self.blue)
 
-def _rgba_from_base(rgba, base):
-    if isinstance(base,ColorValueBase):
+def _rgba_from_base(base):
+    if isinstance(base, RGBAColor):
         return [base.red, base.green, base.blue, base.alpha]
 
 ColorRegistration(
@@ -294,8 +238,8 @@ class Gray(OpaqueColor):
         return TranslucentGray(self.value, 1.0)
 
 # Gray conversion functions.
-def _gray_from_base(gray, base):
-    if isinstance(base,ColorValueBase):
+def _gray_from_base(base):
+    if isinstance(base, RGBAColor):
         g = (base.red+base.green+base.blue)/3.0
         return [g]
         
@@ -326,8 +270,8 @@ class TranslucentGray(TranslucentColor):
         return Gray(self.value)
 
 # Gray conversion functions.
-def _tgray_from_base(gray, base):
-    if isinstance(base,ColorValueBase):
+def _tgray_from_base(base):
+    if isinstance(base, RGBAColor):
         g = (base.red+base.green+base.blue)/3.0
         return [g,base.alpha]
  
@@ -370,13 +314,13 @@ def hsv_from_rgb(r, g, b):
              h+=360.0
      return (h, s, v)
 
-def _hsv_from_base(hsv, base):
-    if isinstance(base, ColorValueBase):
+def _hsv_from_base(base):
+    if isinstance(base, RGBAColor):
         (h, s, v) = hsv_from_rgb(base.red, base.green, base.blue)
         return [h,s,v]
 
-def _hsva_from_base(hsv, base):
-    if isinstance(base, ColorValueBase):
+def _hsva_from_base(base):
+    if isinstance(base, RGBAColor):
         (h, s, v) = hsv_from_rgb(base.red, base.green, base.blue)
         return [h,s,v, base.alpha]
 
