@@ -16,6 +16,9 @@ from ooflib.engine import matrixmethod
 from ooflib.engine import nonlinearsolver
 from ooflib.engine import timestepper
 
+## TODO PYTHON3: Why don't progress bars appear during long equilibrations?
+## TODO PYTHON3: Why is a python trace printed after a convergence failure?
+
 
 class SolverMode(registeredclass.RegisteredClass):
     registry = []
@@ -36,12 +39,10 @@ class BasicSolverMode(SolverMode):
         return nonlinearsolver.NoNonlinearSolver()
     def get_symmetric_solver(self, subproblemcontext, existingSolver):
         solver = self.matrix_method.resolve_symmetric(existingSolver)
-        debug.fmsg("symmetric_solver =", solver)
         return solver
     def get_asymmetric_solver(self, subproblemcontext, existingSolver):
         solver = self.matrix_method.resolve_asymmetric(subproblemcontext, 
                                                      existingSolver)
-        debug.fmsg("asymmetric_solver =", solver)
         return solver
     def derivOrder(self, subproblemcontext):
         pass
