@@ -116,7 +116,8 @@ loadparams = [
     filenameparam.ReadFileNameParameter(
         'filename',
         tip="Name of the file containing the orientation map data."),
-    parameter.RegisteredParameter('reader', orientmapdata.OrientMapReader),
+    parameter.RegisteredParameter('reader', orientmapdata.OrientMapReader,
+                                  tip="Description of the data file format"),
     MicrostructureWithoutOrientMapParameter(
         'microstructure', tip='Add the orientation map to this Microstructure.')
     ]
@@ -130,13 +131,16 @@ mainmenu.OOF.File.Load.addItem(oofmenu.OOFMenuItem(
     discussion =xmlmenudump.loadFile('DISCUSSIONS/orientationmap/menu/load.xml')))
 
 # OOF.OrientationMap.Load is the same as OOF.File.Load.OrientationMap
-orientmapmenu.addItem(oofmenu.OOFMenuItem(
-    'Load',
-    callback=_loadOrientationMap,
-    ordering=0,
-    params=loadparams,
-    help = "Load an orientation map into a Microstructure",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/orientationmap/menu/load.xml')))
+orientmapmenu.addItem(
+    oofmenu.OOFMenuItem(
+        'Load',
+        callback=_loadOrientationMap,
+        ordering=0,
+        params=loadparams,
+        help = "Load an orientation map into a Microstructure",
+        discussion=xmlmenudump.loadFile(
+            'DISCUSSIONS/orientationmap/menu/load.xml')
+    ))
 
 ##############
 
@@ -156,8 +160,9 @@ orientmapmenu.addItem(oofmenu.OOFMenuItem(
     'Delete',
     callback=_deleteOrientationMap,
     ordering=1,
-    params=[MicrostructureWithOrientMapParameter('microstructure',
-                            tip='Remove the orientation map from this Microstructure.')],
+    params=[MicrostructureWithOrientMapParameter(
+        'microstructure',
+        tip='Remove the orientation map from this Microstructure.')],
     help="Remove the orientation map from a Microstructure.",
     discussion=xmlmenudump.loadFile('DISCUSSIONS/orientationmap/menu/remove.xml')))
 
@@ -194,20 +199,27 @@ def msOrientMapFileNameResolver(param, name):
     return ooflib.common.microstructure.microStructures.uniqueName(
         basename.replace(':','.'))
 
-microstructuremenu.micromenu.addItem(oofmenu.OOFMenuItem(
-    'Create_From_OrientationMap_File',
-    callback=_createMSFromOrientationMapFile,
-    params=parameter.ParameterGroup(
-    filenameparam.ReadFileNameParameter(
+microstructuremenu.micromenu.addItem(
+    oofmenu.OOFMenuItem(
+        'Create_From_OrientationMap_File',
+        callback=_createMSFromOrientationMapFile,
+        params=parameter.ParameterGroup(
+            filenameparam.ReadFileNameParameter(
                 'filename',
                 tip='Name of the Orientation Map file.'),
-    parameter.RegisteredParameter('reader', orientmapdata.OrientMapReader),
-    parameter.AutomaticNameParameter('microstructure',
-                                     msOrientMapFileNameResolver,
-                                     automatic.automatic,
-                                     tip='Name of the new Microstructure.')),
-    help="Load an Orientation Map file and create a Microstructure from it.",
-    discussion=xmlmenudump.loadFile('DISCUSSIONS/orientationmap/menu/create.xml')
+            parameter.RegisteredParameter(
+                'reader', orientmapdata.OrientMapReader,
+                tip="The method for reading the file."),
+            parameter.AutomaticNameParameter(
+                'microstructure',
+                msOrientMapFileNameResolver,
+                automatic.automatic,
+                tip='Name of the new Microstructure.')),
+        help="Load an Orientation Map file and create a Microstructure from it.",
+        discussion=xmlmenudump.loadFile(
+            'DISCUSSIONS/orientationmap/menu/create.xml'),
+        xrefs=["Section-Tasks-Microstructure",
+               "MenuItem-OOF.File.Load.OrientationMap"]
     ))
 
 
@@ -281,7 +293,11 @@ mainmenu.debugmenu.addItem(oofmenu.OOFMenuItem(
             value=latticesystem.SpaceGroup(1),
             tip="Lattice symmetry")
         ],
-    help="Print the misorientation (in degrees) between two orientations in thegiven lattice system."))
+    help="Print the misorientation (in degrees) between two orientations in the given lattice system.",
+    discussion="""<para>Print the <link
+    linkend="Section-Concepts-Material-Orientation">misorientation</link>
+    between two 3D orientations in the given lattice system.</para>"""
+))
     
     
 
