@@ -32,6 +32,6 @@ def sensitiveAij(widgetname, **aijs):
             fullwname = base+";"+widgetname+":alpha:"+wijname
             actual = is_sensitive(fullwname)
             if actual != nominal:
-                print >> sys.stderr, "Sensitization test failed for", fullwname
+                print("Sensitization test failed for", fullwname, file=sys.stderr)
                 return 0
     return 1
